# ORM Tango server

A minimalist Tango server that show how to run a PyAML measurement tool,

![Jive configuration](./orm_scan_1.png)

Configuration of the tango server.

![ATKPanel](./orm_scan_2.png)

Plot displaying the scan progress, orbit rms h and v are plotted for each 576 sterrer.
You can guess the effect of the beta function on the top and the coupling on the bottom.

![ATKPanel](./orm_scan_3.png)

The ORM
